Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(466)

Unified Diff: chrome/browser/profiles/profile.h

Issue 11570009: Split PrefService into PrefService, PrefServiceSimple and PrefServiceSyncable. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge to head again, previous had unrelated broken win_rel test. Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/profiles/off_the_record_profile_impl_unittest.cc ('k') | chrome/browser/profiles/profile.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profiles/profile.h
diff --git a/chrome/browser/profiles/profile.h b/chrome/browser/profiles/profile.h
index ded08796dd7fba2f7252c92738de42dd4a4939a5..639985ae860d404b01290e3d61118871cbcfb4cc 100644
--- a/chrome/browser/profiles/profile.h
+++ b/chrome/browser/profiles/profile.h
@@ -24,7 +24,7 @@ class FaviconService;
class GAIAInfoUpdateService;
class HostContentSettingsMap;
class PasswordStore;
-class PrefService;
+class PrefServiceSyncable;
class PromoCounter;
class ProtocolHandlerRegistry;
class TestingProfile;
@@ -138,7 +138,7 @@ class Profile : public content::BrowserContext {
// Profile prefs are registered as soon as the prefs are loaded for the first
// time.
- static void RegisterUserPrefs(PrefService* prefs);
+ static void RegisterUserPrefs(PrefServiceSyncable* prefs);
// Gets task runner for I/O operations associated with |profile|.
static scoped_refptr<base::SequencedTaskRunner> GetTaskRunnerForProfile(
@@ -214,14 +214,15 @@ class Profile : public content::BrowserContext {
// Returns the PolicyService that provides policies for this profile.
virtual policy::PolicyService* GetPolicyService() = 0;
// Retrieves a pointer to the PrefService that manages the preferences
// for this user profile.
- virtual PrefService* GetPrefs() = 0;
+ // TODO(joi): Make this and the below return just a PrefService.
+ virtual PrefServiceSyncable* GetPrefs() = 0;
// Retrieves a pointer to the PrefService that manages the preferences
// for OffTheRecord Profiles. This PrefService is lazily created the first
// time that this method is called.
- virtual PrefService* GetOffTheRecordPrefs() = 0;
+ virtual PrefServiceSyncable* GetOffTheRecordPrefs() = 0;
// Returns the main request context.
virtual net::URLRequestContextGetter* GetRequestContext() = 0;
« no previous file with comments | « chrome/browser/profiles/off_the_record_profile_impl_unittest.cc ('k') | chrome/browser/profiles/profile.cc » ('j') | no next file with comments »
@@ -214,14 +214,15 @@ class Profile : public content::BrowserContext {
// Returns the PolicyService that provides policies for this profile.
virtual policy::PolicyService* GetPolicyService() = 0;
- // Retrieves a pointer to the PrefService that manages the preferences
+ // Retrieves a pointer to the PrefServiceSyncable that manages the preferences
// for this user profile.

Powered by Google App Engine
This is Rietveld 408576698